@@ -1,10 +1,10 @@
 # package global variables
 censobr_env <- new.env(parent = emptyenv()) # nocov start
 
-.onAttach <- function(libname, pkgname){
+.onLoad <- function(libname, pkgname){
 
   # data release
-  censobr_env$data_release <- 'v0.2.0'
+  censobr_env$data_release <- 'v0.3.0'
 
   # local cache dir
   cache_d <- paste0('censobr/data_release_', censobr_env$data_release)
