@@ -31,11 +31,11 @@
 #' # dplyr::glimpse(df)
 #'
 read_mortality <- function(year = 2010,
-                        columns = NULL,
-                        add_labels = NULL,
-                        as_data_frame = FALSE,
-                        showProgress = TRUE,
-                        cache = TRUE){
+                           columns = NULL,
+                           add_labels = NULL,
+                           as_data_frame = FALSE,
+                           showProgress = TRUE,
+                           cache = TRUE){
 
   ### check inputs
   checkmate::assert_numeric(year)
@@ -46,12 +46,12 @@ read_mortality <- function(year = 2010,
   # available for the years:
   years <- c(2010)
   if (isFALSE(year %in% years)) { stop(paste0("Error: Data currently only available for the years ",
-                                              paste(years), collapse = " "))
+                                              paste(years, collapse = " ")))
       }
 
   ### Get url
   file_url <- paste0("https://github.com/ipeaGIT/censobr/releases/download/",
-                     censobr_env$data_release, "/", year, "_deaths_",
+                     censobr_env$data_release, "/", year, "_mortality_",
                      censobr_env$data_release, ".parquet")
 
 
