@@ -10,6 +10,8 @@ testthat::skip_on_cran()
 test_that("interview_manual", {
 
   # download files
+  testthat::expect_message( interview_manual(year = 2022) )
+  testthat::expect_message( interview_manual(year = 2010) )
   testthat::expect_message( interview_manual(year = 2000) )
   testthat::expect_message( interview_manual(year = 1991) )
   testthat::expect_message( interview_manual(year = 1980) )
@@ -20,7 +22,7 @@ test_that("interview_manual", {
   cache_dir <- tools::R_user_dir(pkgv, which = 'cache')
 
   ## check if file have been downloaded
-  years <- c(1970, 1980, 1991, 2000)
+  years <- c(1970, 1980, 1991, 2000, 2010, 2022)
 
   lapply(X=years, FUN = function(y){
     f_address <- paste0(cache_dir,'/',y, '_interview_manual.pdf')
